==> LL_utils-4.1.1.6-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_machines.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)40 1.12 src/ll/config_editor/cgi-bin/show_tab_panel_machines.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:58:24\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(1);

my @normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[0]};
my @editable_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[1]};
my @multi_select_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[2]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_machines.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
if(!defined($dbh))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => DBI->errstr);
	print $tmpl->output;
	exit 1;
}

# Get cluster id and name
my $primary_cluster_id = undef;
my $sql_str="select clusterID,name from TLL_Cluster;";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down_cluster=();
if($sth->fetch())
{
	$primary_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down_cluster, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down_cluster, \%pair;
	}
}
$tmpl->param(pull_down_cluster => \@pull_down_cluster);

# Get the nodeID of default machine
# xyyintodo: in the future, we should check if machine group exists,
#            because we consider using the default machine only when there is no machine group.
my $default_node_id = undef;

# Get node id and name
if(defined($primary_cluster_id))
{
	$sql_str="select nodeID,hostname from TLL_Nodelist where clusterID=".$primary_cluster_id;
	$tmpl->param("TLLR_CFGMachine-clusterID" => $primary_cluster_id);
}
else
{
	$sql_str="select nodeID,hostname from TLL_Nodelist";	
	$tmpl->param("TLLR_CFGMachine-clusterID" => 1);
}
$sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if($name eq "default" || $name eq "Default")
	{
		$default_node_id = $id;
	}
	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_nodeID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_node_id))
	{
		$sql_str="select * from ".$table." where nodeID=".$default_node_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		
		$ary_ref = $sth->fetchrow_arrayref;
	}
	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table." limit 1";
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}

	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		my $default = "";
		if(defined($default_node_id) && defined($ary_ref) && exists $ary_ref->[$m])
		{
			$default = $ary_ref->[$m];
		}

		my %item = (id => $table."-".$sth->{NAME}->[$m],
			    name => $table."-".$sth->{NAME}->[$m],
			    title => $table."-".$sth->{NAME}->[$m],
			    display_name => $sth->{NAME}->[$m],
			    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
			    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
			    default => $default);
		push @table_items, \%item;
	}
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
	
}

# Show editable tables
foreach my $table (@editable_tables_by_nodeID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table." limit 1";
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);
	
	my $default_str = "";
	if(defined($default_node_id))
	{
		$sql_str = "select * from ".$table." where nodeID=".$default_node_id;
		$default_str = get_default_keyword_str($dbh,$sql_str,$table);
	}
	$tmpl->param($table."_default_str" => $default_str);	
}

# Show select tables
foreach my $table (@multi_select_tables_by_nodeID)
{
        $sql_str="select * from ".$table." limit 1";
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);

	my $default_str = "";
	if(defined($default_node_id))
	{
		$sql_str = "select * from ".$table." where nodeID=".$default_node_id;
		$default_str = get_default_keyword_str($dbh,$sql_str,$table);
	}
	$tmpl->param($table."_default_str" => $default_str);	
}
$sth->finish();
$dbh->disconnect();


print "Content-type: text/html\n\n";
print $tmpl->output;

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_machines.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)40 1.13 src/ll/config_editor/cgi-bin/show_tab_panel_machines.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:37:39\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(1);

my @normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[0]};
my @editable_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[1]};
my @multi_select_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machines"}->[2]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_machines.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = get_dbh(1);
if(!defined($dbh))
{
	error_and_exit(DBI->errstr);
}

# Get cluster id and name
my $primary_cluster_id = undef;
my $sql_str="select clusterID,name from TLL_Cluster;";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down_cluster=();
if($sth->fetch())
{
	$primary_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down_cluster, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down_cluster, \%pair;
	}
}
$tmpl->param(pull_down_cluster => \@pull_down_cluster);

# Get the nodeID of default machine
# xyyintodo: in the future, we should check if machine group exists,
#            because we consider using the default machine only when there is no machine group.
my $default_node_id = undef;

# Get node id and name
if(defined($primary_cluster_id))
{
	$sql_str="select nodeID,hostname from TLL_Nodelist where clusterID=".$primary_cluster_id;
	$tmpl->param("TLLR_CFGMachine-clusterID" => $primary_cluster_id);
}
else
{
	$sql_str="select nodeID,hostname from TLL_Nodelist";	
	$tmpl->param("TLLR_CFGMachine-clusterID" => 1);
}
$sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if($name eq "default" || $name eq "Default")
	{
		$default_node_id = $id;
	}
	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_nodeID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_node_id))
	{
		$sql_str="select * from ".$table." where nodeID=".$default_node_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		
		$ary_ref = $sth->fetchrow_arrayref;
	}
	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}

	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		my $default = "";
		if(defined($default_node_id) && defined($ary_ref) && exists $ary_ref->[$m])
		{
			$default = $ary_ref->[$m];
		}

		my %item = (id => $table."-".$sth->{NAME}->[$m],
			    name => $table."-".$sth->{NAME}->[$m],
			    title => $table."-".$sth->{NAME}->[$m],
			    display_name => $sth->{NAME}->[$m],
			    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
			    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
			    default => $default);
		push @table_items, \%item;
	}
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
	
}

# Show editable tables
foreach my $table (@editable_tables_by_nodeID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);
	
	my $default_str = "";
	if(defined($default_node_id))
	{
		$sql_str = "select * from ".$table." where nodeID=".$default_node_id;
		$default_str = get_default_keyword_str($dbh,$sql_str,$table);
	}
	$tmpl->param($table."_default_str" => $default_str);	
}

# Show select tables
foreach my $table (@multi_select_tables_by_nodeID)
{
        $sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);

	my $default_str = "";
	if(defined($default_node_id))
	{
		$sql_str = "select * from ".$table." where nodeID=".$default_node_id;
		$default_str = get_default_keyword_str($dbh,$sql_str,$table);
	}
	$tmpl->param($table."_default_str" => $default_str);	
}
$sth->finish();
$dbh->disconnect();


print "Content-type: text/html\n\n";
print $tmpl->output;
